# Data Directory

This directory contains the data files used in the RAAC Hospital Interactive Maps project.

## Data Source

The hospital data used in this project is sourced from the UK Government's official publication:
[Reinforced autoclaved aerated concrete (RAAC) in hospitals: management information](https://www.gov.uk/government/publications/reinforced-autoclaved-aerated-concrete-raac-in-hospitals-management-information)

This data is part of NHS England's ongoing national RAAC programme, which has been allocated £954 million since the 2021 to 2022 financial year for remediation and failsafe measures.

## Files

### Source Data File

- `hospital-sites-with-confirmed-raac-in-england-3-october-2024.csv`
  - This is the original data file downloaded from the UK Government website
  - Contains the following columns:
    - Region
    - Trust
    - Site Notes (Hospital Name)
    - RAAC Status
  - This file needs to be converted to Excel format and enhanced with additional information

### Input File

- `NGL15- Hospital_sites_with_confirmed_RAAC_list.xlsx`
  - This is the enhanced version of the CSV file
  - Created by converting the CSV to Excel format and adding required columns
  - Must be placed in this directory
  - Required columns:
    - Hospital Name (from Site Notes in CSV)
    - Address (needs to be added manually)
    - Postcode (needs to be added manually)
  - Optional columns:
    - RAAC Status (from CSV)
    - Building Name (can be extracted from Site Notes)
    - Notes (can be added for additional information)
  - Example format:
    ```
    Hospital Name | Address                    | Postcode  | RAAC Status | Building Name | Notes
    -------------|----------------------------|-----------|-------------|---------------|-------
    Hospital A   | 123 Main Street, City      | AB12 3CD  | Confirmed   | Main Block    | ...
    Hospital B   | 456 High Road, Town        | EF45 6GH  | Suspected   | East Wing     | ...
    ```

### Generated File

- `coordinates.xlsx`
  - This file is generated by `step1_get_coordinates.py`
  - Will be created in this directory
  - Contains the original hospital data plus:
    - Latitude coordinates
    - Longitude coordinates
    - Geocoding status
  - Used by `step2_create_map.py` to generate the interactive map
  - The interactive map will be saved as `index.html` in the root directory

## Usage

1. Place your hospital data file in this directory

   - Download the CSV file from the official website
   - Convert it to Excel format
   - Add the required columns:
     - Address (manually)
     - Postcode (manually)
   - Save as: `NGL15- Hospital_sites_with_confirmed_RAAC_list.xlsx`
   - Ensure it contains all required columns

2. Run the scripts in sequence:

   ```bash
   python ../src/step1_get_coordinates.py
   python ../src/step2_create_map.py
   ```

3. Check the generated files:
   - `coordinates.xlsx` will appear in this directory
   - `index.html` will appear in the root directory

## Notes

- Keep your original input file as a backup
- The coordinates file will be overwritten each time you run step1
- If geocoding fails for any addresses, check the coordinates file for "Coordinates not found"
- The interactive map will be saved in the root directory, not in this data directory
- The data is regularly updated by the UK Government, so check the source link for the latest information
- Remember to manually add postcodes and addresses to the Excel file after downloading from the official website
- The CSV file contains the official data, while the Excel file is an enhanced version with additional required information
