# Source Code Directory

This directory contains the Python scripts used to generate the RAAC Hospital Interactive Maps.

## Scripts

### step1_get_coordinates.py

- Purpose: Converts hospital addresses to geographic coordinates
- Input: `../data/NGL15- Hospital_sites_with_confirmed_RAAC_list.xlsx`
  - Must be placed in the data directory
  - Must contain required columns: Hospital Name, Address, Postcode
- Output: `../data/coordinates.xlsx`
  - Generated in the data directory
  - Contains original data plus latitude and longitude columns
- Dependencies:
  - pandas
  - geopy
  - openpyxl

### step2_create_map.py

- Purpose: Generates an interactive map from the coordinates
- Input: `../data/coordinates.xlsx`
  - Must be generated by step1_get_coordinates.py first
  - Must contain latitude and longitude columns
- Output: `../index.html`
  - Interactive map will be saved in the root folder
  - Can be opened in any web browser
  - Contains clickable markers for each hospital
- Dependencies:
  - pandas
  - folium
  - openpyxl

## Usage

1. Ensure all dependencies are installed:

   ```bash
   pip install -r ../requirements.txt
   ```

2. Run the scripts in sequence:
   ```bash
   python step1_get_coordinates.py
   python step2_create_map.py
   ```

## Notes

- Both scripts must be run in order
- Internet connection is required for geocoding in step1
- The generated map will be saved as `index.html` in the root directory
- If you get any errors:
  - Check that the input Excel file is in the correct location
  - Verify that the input file has all required columns
  - Ensure you have an internet connection for geocoding
  - Check that the coordinates file was generated successfully
